@@ -33,9 +33,10 @@
 #include "queries.h"
 
 #include <KIO/JobTracker>
+#include <KIO/JobUiDelegate>
+#include <KIO/OpenUrlJob>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KRun>
 #include <KWidgetJobTracker>
 
 #include <QDir>
@@ -118,7 +119,7 @@ void BatchExtract::slotStartJob()
 
     KIO::getJobTracker()->registerJob(this);
 
-    emit description(this,
+    Q_EMIT description(this,
                      i18n("Extracting Files"),
                      qMakePair(i18n("Source archive"), m_fileNames.value(subjobs().at(0)).first),
                      qMakePair(i18n("Destination"), m_fileNames.value(subjobs().at(0)).second)
@@ -171,16 +172,18 @@ void BatchExtract::slotResult(KJob *job)
 
     if (!hasSubjobs()) {
         if (openDestinationAfterExtraction()) {
-            QUrl destination(destinationFolder());
-            destination.setPath(QDir::cleanPath(destination.path()));
-            KRun::runUrl(destination, QStringLiteral("inode/directory"), nullptr, KRun::RunExecutables, QString(), QByteArray());
+            const QString path = QDir::cleanPath(destinationFolder());
+            const QUrl destination(QUrl::fromLocalFile(path));
+            KIO::OpenUrlJob *job = new KIO::OpenUrlJob(destination, QStringLiteral("inode/directory"));
+            job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, nullptr));
+            job->start();
         }
 
         qCDebug(ARK) << "Finished, emitting the result";
         emitResult();
     } else {
         qCDebug(ARK) << "Starting the next job";
-        emit description(this,
+        Q_EMIT description(this,
                          i18n("Extracting Files"),
                          qMakePair(i18n("Source archive"), m_fileNames.value(subjobs().at(0)).first),
                          qMakePair(i18n("Destination"), m_fileNames.value(subjobs().at(0)).second)
@@ -284,22 +287,33 @@ bool BatchExtract::showExtractDialog()
         loadJob->start();
     }
 
-    if (!dialog.data()->exec()) {
-        if (loadJob) {
-            loadJob->kill();
-            loadJob->deleteLater();
+    QUrl destinationDirectory;
+    if (dialog.data()->exec()) {
+        destinationDirectory = dialog.data()->destinationDirectory();
+        if (destinationDirectory.isLocalFile()) {
+            setAutoSubfolder(false && dialog.data()->autoSubfolders());
+            setDestinationFolder(destinationDirectory.toLocalFile());
+            setOpenDestinationAfterExtraction(dialog.data()->openDestinationAfterExtraction());
+            setPreservePaths(dialog.data()->preservePaths());
+
+            delete dialog.data();
+            return true;
         }
-        delete dialog.data();
-        return false;
     }
 
-    setAutoSubfolder(dialog.data()->autoSubfolders());
-    setDestinationFolder(dialog.data()->destinationDirectory().toDisplayString(QUrl::PreferLocalFile));
-    setOpenDestinationAfterExtraction(dialog.data()->openDestinationAfterExtraction());
-    setPreservePaths(dialog.data()->preservePaths());
+    // we get here if no directory was chosen, or the chosen directory is not local
+    if (loadJob) {
+        loadJob->kill();
+        loadJob->deleteLater();
+    }
+
+    if (!destinationDirectory.isEmpty() && !destinationDirectory.isLocalFile()) {
+        KMessageBox::error(nullptr,
+                            xi18nc("@info", "The archive could not be extracted to <filename>%1</filename> because Ark can only extract to local destinations.", destinationDirectory.toDisplayString()));
+    }
 
     delete dialog.data();
 
-    return true;
+    return false;
 }
 
