@@ -25,6 +25,7 @@
 #include <QMimeDatabase>
 
 #include <KDialogJobUiDelegate>
+#include <KFileItem>
 #include <KIO/ApplicationLauncherJob>
 #include <KLocalizedString>
 #include <KPluginFactory>
@@ -45,8 +46,8 @@ CompressFileItemAction::CompressFileItemAction(QObject* parent, const QVariantLi
 
 QList<QAction*> CompressFileItemAction::actions(const KFileItemListProperties& fileItemInfos, QWidget* parentWidget)
 {
-    // #268163: don't offer compression on already compressed archives.
-    if (m_pluginManager->supportedMimeTypes().contains(fileItemInfos.mimeType())) {
+    // #268163: don't offer compression on already compressed archives, unless the user selected 2 or more of them.
+    if (fileItemInfos.items().count() == 1 && m_pluginManager->supportedMimeTypes().contains(fileItemInfos.mimeType())) {
         return {};
     }
 
