@@ -38,7 +38,7 @@ void CliUnarchiverTest::initTestCase()
     m_plugin = new Plugin(this);
     const auto plugins = m_pluginManger.availablePlugins();
     for (Plugin *plugin : plugins) {
-        if (plugin->metaData().pluginId() == QStringLiteral("kerfuffle_cliunarchiver")) {
+        if (plugin->metaData().pluginId() == QLatin1String("kerfuffle_cliunarchiver")) {
             m_plugin = plugin;
             return;
         }
