@@ -152,8 +152,8 @@ public:
     static QStringList entryPathsFromDestination(QStringList entries, const Archive::Entry *destination, int entriesWithoutChildren);
 
     /**
-     * @return true if the interface has killed the job or if it will stop it as soon as possible.
-     * Otherwise returns false if the interface is not able to kill the operation.
+     * @return true if the interface has killed the job.
+     * Otherwise returns false if the interface is not able to instantly kill the operation.
      */
     virtual bool doKill();
 
@@ -262,6 +262,9 @@ public:
 Q_SIGNALS:
     void entryRemoved(const QString &path);
 
+protected:
+    OperationMode m_operationMode = NoOperation;
+
 private Q_SLOTS:
     void onEntryRemoved(const QString &path);
 };
