@@ -58,7 +58,7 @@ private:
     bool writeEntry(zip_t *archive, const QString &entry, const Archive::Entry* destination, const CompressionOptions& options, bool isDir = false);
     bool emitEntryForIndex(zip_t *archive, qlonglong index);
     void emitProgress(double percentage);
-    QString permissionsToString(const mode_t &perm);
+    QString permissionsToString(mode_t perm);
     static void progressCallback(zip_t *, double progress, void *that);
 
     QVector<Archive::Entry*> m_emittedEntries;
